from setuptools import setup, find_packages

setup(
    name="JarvisSTT-ItsArsh",
    version="0.1",
    author="Anubhav Chaturvedi",
    author_email="example@gmail.com",
    description="This is a speech to text package",
    install_requires=["selenium", "webdriver-manager"],
    packages=find_packages(),
)